/***********************************************************************************************************************
 *
 * OpenBlueSky - NetBeans Platform Enhancements
 * Copyright (C) 2006-2011 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://openbluesky.java.net
 * SCM: https://bitbucket.org/tidalwave/openbluesky-src
 *
 **********************************************************************************************************************/
package it.tidalwave.swing;

import javax.annotation.Nonnull;
import it.tidalwave.util.As;
import it.tidalwave.role.Displayable;
import it.tidalwave.role.spi.DefaultDisplayable;
import org.junit.Test;
import org.openide.util.Lookup;
import org.openide.util.lookup.Lookups;
import static org.junit.Assert.*;
import static org.mockito.Mockito.*;
import static org.hamcrest.CoreMatchers.*;

/***********************************************************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id: $
 *
 **********************************************************************************************************************/
public class DisplayNameListCellRendererTest
  {
    public static interface Mock
      {
        @Nonnull
        public String getDisplayName();
      }

    @Test
    public void shouldWorkWithAClassProvidingGetDisplayName()
      {
        final Mock mock = mock(Mock.class);
        when(mock.getDisplayName()).thenReturn("the display name");
        final DisplayNameListCellRenderer<Mock> fixture = new DisplayNameListCellRenderer<Mock>(Mock.class);
        assertThat(fixture.getDisplayName(mock), is("the display name"));
      }

    @Test
    public void shouldWorkWithALookupProviderProvidingDisplayable()
      {
        final Lookup.Provider mock = mock(Lookup.Provider.class);
        final Lookup lookup = Lookups.fixed(new DefaultDisplayable("the display name", ""));
        when(mock.getLookup()).thenReturn(lookup);
        final DisplayNameListCellRenderer<Object> fixture = new DisplayNameListCellRenderer<Object>(Object.class);
        assertThat(fixture.getDisplayName(mock), is("the display name"));
      }
    
    @Test
    public void shouldWorkWithAsProviderProvidingDisplayable()
      {
        final As mock = mock(As.class);
        when(mock.as(eq(Displayable.class))).thenReturn(new DefaultDisplayable("the display name", ""));
        final DisplayNameListCellRenderer<Object> fixture = new DisplayNameListCellRenderer<Object>(Object.class);
        assertThat(fixture.getDisplayName(mock), is("the display name"));
      }
  }
